"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CommandFactory = void 0;
const node_assert_1 = require("node:assert");
const WebConsoleArchivalCommand_1 = require("./driving/command/WebConsoleArchivalCommand");
const WebConsoleArchivalHandler_1 = require("./feature/WebConsoleArchivalHandler");
const WebConsoleCreateCommand_1 = require("./driving/command/WebConsoleCreateCommand");
const WebConsoleCreateHandler_1 = require("./feature/WebConsoleCreateHandler");
var LogWorkerActionEnum;
(function (LogWorkerActionEnum) {
    LogWorkerActionEnum["ARCHIVAL"] = "archival";
    LogWorkerActionEnum["INSERTION"] = "insertion";
})(LogWorkerActionEnum || (LogWorkerActionEnum = {}));
class CommandFactory {
    static getHandler(logServicePayload) {
        const { payload, eventType } = logServicePayload;
        if (eventType === LogWorkerActionEnum.ARCHIVAL) {
            const archivalCommand = new WebConsoleArchivalCommand_1.WebConsoleArchivalCommand(payload);
            archivalCommand.validate();
            return new WebConsoleArchivalHandler_1.WebConsoleArchivalHandler(archivalCommand);
        }
        if (eventType === LogWorkerActionEnum.INSERTION) {
            const insertionCommand = new WebConsoleCreateCommand_1.WebConsoleCreateCommand(payload);
            insertionCommand.validate();
            return new WebConsoleCreateHandler_1.WebConsoleCreateHandler(insertionCommand);
        }
        throw new node_assert_1.AssertionError({ message: 'Unsupported Command' });
    }
}
exports.CommandFactory = CommandFactory;
//# sourceMappingURL=CommandFactory.js.map