"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LogWorker = void 0;
const node_util_1 = require("node:util");
const node_assert_1 = require("node:assert");
const logger_1 = require("@jfrog-pipelines/logger");
const utility_1 = require("@jfrog-pipelines/utility");
const CommandFactory_1 = require("./CommandFactory");
const milliSecondToSecondIndex = 1000;
const BytesToKbIndex = 1024;
const KbToMbIndex = 1024;
class LogWorker {
    constructor() {
        this.logger = logger_1.LoggerFactory.getLogger('LogWorker');
    }
    async process(message) {
        if (!message || !message.payload || !(0, utility_1.isObject)(message.payload)) {
            throw new node_assert_1.AssertionError({ message: `Invalid message received. Received Message:${(0, node_util_1.inspect)(message)}` });
        }
        const start = Date.now();
        const handler = CommandFactory_1.CommandFactory.getHandler(message.payload);
        await handler.handle();
        const end = Date.now();
        const timeInSeconds = (end - start) / milliSecondToSecondIndex;
        const memoryConsumed = process.memoryUsage().heapUsed / BytesToKbIndex / KbToMbIndex;
        this.logger.info(`\n LogWorker cycle took ${timeInSeconds} seconds and ${memoryConsumed} MB of memory \n`);
    }
}
exports.LogWorker = LogWorker;
//# sourceMappingURL=LogWorker.js.map