"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const CommandFactory_1 = require("../CommandFactory");
describe('CommandFactory tests', () => {
    it('should be defined', () => {
        const commandFactory = new CommandFactory_1.CommandFactory();
        expect(commandFactory).toBeDefined();
    });
    it("should return WebConsoleArchivalHandler if payload 's eventType is 'archival'", () => {
        const payload = {
            eventType: 'archival',
            payload: { objectId: 1, objectType: 'step' }
        };
        const result = CommandFactory_1.CommandFactory.getHandler(payload);
        const expectedResult = {
            webConsoleArchivalCommand: { payload: { objectId: 1, objectType: 'step' } }
        };
        expect(result).toEqual(expectedResult);
    });
    it("should throw error if payload 's eventType node supported", () => {
        const payload = {
            eventType: '<eventType>',
            payload: { objectId: 1, objectType: 'step' }
        };
        expect(() => CommandFactory_1.CommandFactory.getHandler(payload)).toThrow('Unsupported Command');
    });
    it("should throw error if payload's  objectType 'steplet' and eventType is 'archival'", () => {
        const payload = {
            eventType: 'archival',
            payload: { objectId: 1, objectType: 'steplet' }
        };
        expect(() => CommandFactory_1.CommandFactory.getHandler(payload)).toThrow("Invalid objectType received. Expected either 'step' or 'steplet', received 'steplet'");
    });
    it("should return WebConsoleCreateHandler if payload 's eventType is 'insertion'", () => {
        const payload = {
            eventType: 'insertion',
            payload: { objectId: 1, objectType: 'step' }
        };
        const result = CommandFactory_1.CommandFactory.getHandler(payload);
        const expectedResult = {
            command: { payload: { objectId: 1, objectType: 'step' }, logger: { moduleName: 'InsertRepository' } },
            logger: { moduleName: 'WebConsoleCreateCommandHandler' }
        };
        expect(result).toEqual(expectedResult);
    });
});
//# sourceMappingURL=CommandFactory.test.js.map