"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const logger_1 = require("@jfrog-pipelines/logger");
const LogWorker_1 = require("../LogWorker");
const CommandFactory_1 = require("../CommandFactory");
jest.mock('@jfrog-pipelines/logger', () => {
    const actualTracker = jest.requireActual('@jfrog-pipelines/logger');
    return {
        ...actualTracker,
        LoggerFactory: {
            getLogger: jest.fn().mockReturnValue({
                info: jest.fn(),
                error: jest.fn(),
                debug: jest.fn(),
                trace: jest.fn(),
                warn: jest.fn()
            })
        }
    };
});
const logger = logger_1.LoggerFactory.getLogger();
describe('LogWorker Tests', () => {
    const logWorker = new LogWorker_1.LogWorker();
    it('should be defined', () => {
        expect(logWorker).toBeDefined();
    });
    it('should throw error when message is undefined', async () => {
        const message = undefined;
        await expect(logWorker.process(message)).rejects.toThrow('Invalid message received. Received Message:undefined');
    });
    it('should throw error when message.payload is undefined', async () => {
        const message = { payload: undefined };
        await expect(logWorker.process(message)).rejects.toThrow('Invalid message received. Received Message:{ payload: undefined }');
    });
    it('should throw error if message.payload is not an object', async () => {
        const message = { payload: 1 };
        await expect(logWorker.process(message)).rejects.toThrow('Invalid message received. Received Message:{ payload: 1 }');
    });
    it('should process a valid message', async () => {
        const validMessage = {
            payload: {}
        };
        const mockHandler = {
            handle: jest.fn()
        };
        jest.spyOn(CommandFactory_1.CommandFactory, 'getHandler').mockReturnValue(mockHandler);
        await logWorker.process(validMessage);
        expect(CommandFactory_1.CommandFactory.getHandler).toHaveBeenCalledWith(validMessage.payload);
        expect(mockHandler.handle).toHaveBeenCalledTimes(1);
    });
    it('should log time and memory consumed', async () => {
        const validMessage = {
            payload: {}
        };
        const mockHandler = {
            handle: jest.fn()
        };
        jest.spyOn(CommandFactory_1.CommandFactory, 'getHandler').mockReturnValue(mockHandler);
        await logWorker.process(validMessage);
        expect(logger.info).toHaveBeenCalledWith(expect.stringContaining('LogWorker cycle took'));
    });
});
//# sourceMappingURL=LogWorker.test.js.map