"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Step = void 0;
const metadata_1 = require("@jfrog-pipelines/metadata");
const StepServiceRepository_1 = require("./StepServiceRepository");
class Step {
    constructor(stepId, external, stepStatus) {
        this.id = stepId;
        this.isExternal = external;
        this.status = stepStatus;
    }
    static async create(stepId) {
        const stepServiceRepository = new StepServiceRepository_1.StepServiceRepository(stepId);
        const stepEntity = await stepServiceRepository.getStepById(stepId);
        if (stepEntity === null) {
            return null;
        }
        const isExternal = stepEntity.configPropertyBag.isExternal === true;
        const statusCode = stepEntity.statusCode;
        const stepStatus = metadata_1.STATUS_CODE_TEXT_MAP[statusCode].toUpperCase();
        return new Step(stepId, isExternal, stepStatus);
    }
    isExecutionLogsNotAvaiable() {
        if (this.isExternal) {
            return true;
        }
        if (this.status === 'SKIPPED') {
            return true;
        }
        return false;
    }
    getId() {
        return this.id;
    }
}
exports.Step = Step;
//# sourceMappingURL=Step.js.map