"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StepConsoleRepository = void 0;
const node_util_1 = require("node:util");
const data_access_layer_1 = require("@jfrog-pipelines/data-access-layer");
const logger_1 = require("@jfrog-pipelines/logger");
const StepConsoleDao_1 = require("../../driven/StepConsoleDao");
const RetryAwareStepConsoleDao_1 = require("../../driven/RetryAwareStepConsoleDao");
class StepConsoleRepository {
    constructor(stepId) {
        this.stepId = stepId;
        this.logger = logger_1.LoggerFactory.getLogger(`StepConsoleRepository:${this.stepId}`);
        this.retryAwareStepConsoleDao = new RetryAwareStepConsoleDao_1.RetryAwareStepConsoleDao();
        this.stepConsoleDao = new StepConsoleDao_1.StepConsoleDao();
    }
    async getStepLogsByStepId(stepId) {
        try {
            const query = new data_access_layer_1.SequelizeQueryBuilder({}).where('stepId', stepId);
            return await this.stepConsoleDao.findAll(query.build());
        }
        catch (error) {
            this.logger.warn(`Cannot extract StepConsole logs for the stepId:${stepId}. Error:${(0, node_util_1.inspect)(error)}`);
            return [];
        }
    }
    async deleteStepLogs(stepId) {
        try {
            const deletedCount = await this.retryAwareStepConsoleDao.delete({
                where: {
                    $stepId$: stepId
                }
            });
            this.logger.info(`Deleted ${deletedCount} stepConsole records`);
        }
        catch (error) {
            this.logger.warn(`Step logs cannot be deleted due to error:${(0, node_util_1.inspect)(error)}`);
        }
    }
}
exports.StepConsoleRepository = StepConsoleRepository;
//# sourceMappingURL=StepConsoleRepository.js.map