"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StepConsoleRootAggregate = void 0;
const logger_1 = require("@jfrog-pipelines/logger");
const StepletConsoleAggregate_1 = require("./StepletConsoleAggregate");
const StepServiceRepository_1 = require("./StepServiceRepository");
const StepConsoleRepository_1 = require("./StepConsoleRepository");
const FileStoreRepository_1 = require("./file-store/FileStoreRepository");
const Step_1 = require("./Step");
const NoopFileStrategy_1 = require("./file-store/NoopFileStrategy");
class StepConsoleRootAggregate {
    constructor(stepId) {
        this.logger = logger_1.LoggerFactory.getLogger('StepConsoleRootAggregate');
        this.stepConsoleRepository = new StepConsoleRepository_1.StepConsoleRepository(stepId);
        this.stepServiceRepository = new StepServiceRepository_1.StepServiceRepository(stepId);
        this.fileStoreRepository = new FileStoreRepository_1.FileStoreRepository(stepId);
    }
    async archive(stepId) {
        const step = await Step_1.Step.create(stepId);
        if (step === null) {
            this.logger.warn(`Invalid stepId received stepId: ${stepId}`);
            return;
        }
        if (step.isExecutionLogsNotAvaiable()) {
            this.fileStoreRepository.setStrategy(new NoopFileStrategy_1.NoopFileStrategy());
        }
        await this.fileStoreRepository.cleanTempFolder();
        const stepConsoleLogs = await this.stepConsoleRepository.getStepLogsByStepId(stepId);
        const stepletIds = await this.stepServiceRepository.getStepletIdsByStepId(stepId);
        for (const stepletId of stepletIds) {
            const stepletConsoleAggregate = new StepletConsoleAggregate_1.StepletConsoleAggregate(stepId, this.fileStoreRepository);
            await stepletConsoleAggregate.archive(stepletId, stepConsoleLogs);
        }
        await this.stepConsoleRepository.deleteStepLogs(stepId);
        await this.fileStoreRepository.cleanTempFolder();
    }
}
exports.StepConsoleRootAggregate = StepConsoleRootAggregate;
//# sourceMappingURL=StepConsoleRootAggregate.js.map