"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StepServiceRepository = void 0;
const node_util_1 = require("node:util");
const logger_1 = require("@jfrog-pipelines/logger");
const StepServiceDataAdapter_1 = require("../../driven/acl/step-service/StepServiceDataAdapter");
const ArtifactoryUrlVo_1 = require("./ArtifactoryUrlVo");
class StepServiceRepository {
    constructor(stepId) {
        this.stepId = stepId;
        this.logger = logger_1.LoggerFactory.getLogger(`StepServiceRepository:${this.stepId}`);
        this.stepServiceDataAdapter = new StepServiceDataAdapter_1.StepServiceDataAdapter();
    }
    async getStepletIdsByStepId(stepId) {
        try {
            const steplets = await this.stepServiceDataAdapter.getStepletsByStepId(stepId);
            const stepletIds = steplets.map((steplet) => {
                return steplet.id;
            });
            return stepletIds;
        }
        catch (error) {
            this.logger.warn(`Cannot find stepletIds for the stepId:${stepId}. Error:${(0, node_util_1.inspect)(error)}`);
            return [];
        }
    }
    async getArtifactoryUrlsByStepId(stepId, artifactName) {
        try {
            const artifactoryUrls = await this.stepServiceDataAdapter.getArtifactoryUrlByStepId(stepId, artifactName);
            return new ArtifactoryUrlVo_1.ArtifactoryUrlVo(artifactoryUrls);
        }
        catch (error) {
            this.logger.warn(`Cannot get Artifactory Urls. Error:, ${(0, node_util_1.inspect)(error)}`);
            return null;
        }
    }
    async markConsoleArchived(stepletId) {
        try {
            await this.stepServiceDataAdapter.updateConsoleArchived(stepletId);
            return;
        }
        catch (error) {
            this.logger.warn(`Cannot update consoleArchived value to error for stepletId: ${stepletId} due to error: ${(0, node_util_1.inspect)(error)}`);
        }
    }
    async getStepById(stepId) {
        try {
            const step = await this.stepServiceDataAdapter.getStepById(stepId);
            return step;
        }
        catch (error) {
            this.logger.warn(`failed to fetch step for stepId: ${stepId} due to error: ${(0, node_util_1.inspect)(error)}`);
            return null;
        }
    }
}
exports.StepServiceRepository = StepServiceRepository;
//# sourceMappingURL=StepServiceRepository.js.map