"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StepletConsoleAggregate = void 0;
const StepletConsoleRepository_1 = require("./StepletConsoleRepository");
const StepServiceRepository_1 = require("./StepServiceRepository");
class StepletConsoleAggregate {
    constructor(stepId, fileStoreRepository) {
        this.stepId = stepId;
        this.fileStoreRepository = fileStoreRepository;
        this.stepletConsoleRepository = new StepletConsoleRepository_1.StepletConsoleRepository(stepId);
        this.stepServiceRepository = new StepServiceRepository_1.StepServiceRepository(stepId);
    }
    async archive(stepletId, stepConsoleLogs) {
        const filePath = await this.fileStoreRepository.createLogFile(stepletId);
        if (filePath) {
            await this.fileStoreRepository.appendStepConsoles(filePath, stepConsoleLogs);
            const stepletSetupAndCleanUpLogs = await this.stepletConsoleRepository.getSetupAndCleanupLogs(stepletId);
            const artifactName = `steplet_${stepletId}_consoles.gz`;
            const artifactUrlVo = await this.stepServiceRepository.getArtifactoryUrlsByStepId(this.stepId, artifactName);
            await this.fileStoreRepository.appendSetupConsoles(filePath, stepletSetupAndCleanUpLogs);
            if (artifactUrlVo) {
                await this.fileStoreRepository.appendExecutionLogs(filePath, artifactUrlVo.getUrl, artifactUrlVo.getToken, stepletId);
            }
            await this.fileStoreRepository.appendCleanupConsoles(filePath, stepletSetupAndCleanUpLogs);
            if (artifactUrlVo) {
                await this.fileStoreRepository.uploadToArtifactory(filePath, artifactUrlVo.putUrl, artifactUrlVo.getToken);
            }
            await this.fileStoreRepository.deleteFile(filePath);
        }
        await Promise.all([
            this.stepServiceRepository.markConsoleArchived(stepletId),
            this.stepletConsoleRepository.deleteStepletLogs(stepletId)
        ]);
    }
}
exports.StepletConsoleAggregate = StepletConsoleAggregate;
//# sourceMappingURL=StepletConsoleAggregate.js.map