"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StepletConsoleRepository = void 0;
const node_util_1 = require("node:util");
const logger_1 = require("@jfrog-pipelines/logger");
const StepletConsoleDao_1 = require("../../driven/StepletConsoleDao");
const RetryAwareStepletConsoleDao_1 = require("../../driven/RetryAwareStepletConsoleDao");
class StepletConsoleRepository {
    constructor(stepId) {
        this.stepId = stepId;
        this.logger = logger_1.LoggerFactory.getLogger(`StepletConsoleRepository:${this.stepId}`);
        this.stepletConsoleDao = new StepletConsoleDao_1.StepletConsoleDao();
        this.retryAwareStepletConsoleDao = new RetryAwareStepletConsoleDao_1.RetryAwareStepletConsoleDao();
    }
    async getSetupAndCleanupLogs(stepletId) {
        try {
            const stepletLogs = await this.stepletConsoleDao.findAll({
                where: {
                    $stepletId$: stepletId,
                    $stage$: {
                        $in: ['setup', 'cleanup']
                    }
                }
            });
            const setupAndCleanupLogsByStage = this.groupByStage(stepletLogs);
            return setupAndCleanupLogsByStage;
        }
        catch (error) {
            this.logger.warn(`Cannot get setup and clean up logs due to error:${(0, node_util_1.inspect)(error)}`);
            return new Map();
        }
    }
    async deleteStepletLogs(stepletId) {
        try {
            const deletedCount = await this.retryAwareStepletConsoleDao.delete({
                where: {
                    $stepletId$: stepletId
                }
            });
            this.logger.info(`Deleted ${deletedCount} stepletConsole records`);
        }
        catch (error) {
            this.logger.warn(`Steplet logs cannot be deleted due to error:${(0, node_util_1.inspect)(error)}`);
        }
    }
    groupByStage(stepletLogs) {
        const stepletLogsByStage = new Map();
        for (const log of stepletLogs) {
            const logs = stepletLogsByStage.get(log.stage) ?? [];
            logs.push(log);
            stepletLogsByStage.set(log.stage, logs);
        }
        return stepletLogsByStage;
    }
}
exports.StepletConsoleRepository = StepletConsoleRepository;
//# sourceMappingURL=StepletConsoleRepository.js.map