"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Step_1 = require("../Step");
const StepServiceRepository_1 = require("../StepServiceRepository");
jest.mock('@jfrog-pipelines/configuration', () => ({
    ConfigFactory: {
        config: {
            rtUiUrl: 'http://example.com'
        }
    }
}));
describe('Step tests', () => {
    it('should return false if execution logs are available if the step is not an external step', () => {
        const stepId = 1;
        const external = false;
        const stepStatus = 'SUCCESS';
        const step = new Step_1.Step(stepId, external, stepStatus);
        const hasLogs = step.isExecutionLogsNotAvaiable();
        expect(hasLogs).toStrictEqual(false);
    });
    it('should return true if execution logs are not available if the step is  an external step', () => {
        const stepId = 1;
        const external = true;
        const stepStatus = 'SUCCESS';
        const step = new Step_1.Step(stepId, external, stepStatus);
        const hasLogs = step.isExecutionLogsNotAvaiable();
        expect(hasLogs).toStrictEqual(true);
    });
    it('should return true if execution logs are not available if the step is "SKIPPED"', () => {
        const stepId = 1;
        const external = false;
        const stepStatus = 'SKIPPED';
        const step = new Step_1.Step(stepId, external, stepStatus);
        const hasLogs = step.isExecutionLogsNotAvaiable();
        expect(hasLogs).toStrictEqual(true);
    });
    it('should return null if getStepById returns null', async () => {
        const stepId = 1;
        const getStepByIdSpied = jest.spyOn(StepServiceRepository_1.StepServiceRepository.prototype, 'getStepById').mockResolvedValueOnce(null);
        const result = await Step_1.Step.create(stepId);
        expect(getStepByIdSpied).toHaveBeenCalledTimes(1);
        expect(getStepByIdSpied).toHaveBeenCalledWith(stepId);
        expect(result).toStrictEqual(null);
    });
    it('should create Step if step is a external step', async () => {
        const stepId = 1;
        const mockStepData = {
            id: 1,
            statusCode: 4001,
            configPropertyBag: {
                isExternal: true
            }
        };
        const getStepByIdSpied = jest
            .spyOn(StepServiceRepository_1.StepServiceRepository.prototype, 'getStepById')
            .mockResolvedValueOnce(mockStepData);
        await Step_1.Step.create(stepId);
        expect(getStepByIdSpied).toHaveBeenCalledTimes(1);
        expect(getStepByIdSpied).toHaveBeenCalledWith(stepId);
    });
    it('should create Step if step is a skipped step', async () => {
        const stepId = 1;
        const mockStepData = {
            id: 1,
            statusCode: 4008,
            configPropertyBag: {
                isExternal: true
            }
        };
        const getStepByIdSpied = jest
            .spyOn(StepServiceRepository_1.StepServiceRepository.prototype, 'getStepById')
            .mockResolvedValueOnce(mockStepData);
        await Step_1.Step.create(stepId);
        expect(getStepByIdSpied).toHaveBeenCalledTimes(1);
        expect(getStepByIdSpied).toHaveBeenCalledWith(stepId);
    });
    it('should get id', () => {
        const stepId = 1;
        const external = false;
        const stepStatus = 'SUCCESS';
        const step = new Step_1.Step(stepId, external, stepStatus);
        const expectedId = step.getId();
        expect(expectedId).toStrictEqual(stepId);
    });
});
//# sourceMappingURL=Step.test.js.map