"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const logger_1 = require("@jfrog-pipelines/logger");
const StepConsoleDao_1 = require("../../../driven/StepConsoleDao");
const StepConsoleRepository_1 = require("../StepConsoleRepository");
const RetryAwareStepConsoleDao_1 = require("../../../driven/RetryAwareStepConsoleDao");
jest.mock('@jfrog-pipelines/logger', () => {
    const actualTracker = jest.requireActual('@jfrog-pipelines/logger');
    return {
        ...actualTracker,
        LoggerFactory: {
            getLogger: jest.fn().mockReturnValue({
                info: jest.fn(),
                error: jest.fn(),
                debug: jest.fn(),
                trace: jest.fn(),
                warn: jest.fn()
            })
        }
    };
});
const logger = logger_1.LoggerFactory.getLogger();
describe('StepletConsoleRepository tests', () => {
    it('should be defined', () => {
        const stepId = 1;
        const stepConsoleRepository = new StepConsoleRepository_1.StepConsoleRepository(stepId);
        expect(stepConsoleRepository).toBeDefined();
    });
    it('should getStepLogsByStepId from the database', async () => {
        const stepConsoleRepository = new StepConsoleRepository_1.StepConsoleRepository(1);
        const findAllSpied = jest
            .spyOn(StepConsoleDao_1.StepConsoleDao.prototype, 'findAll')
            .mockResolvedValueOnce([{ consoleId: '1', stepId: 1 }]);
        const stepLogsFromDatabase = await stepConsoleRepository.getStepLogsByStepId(1);
        expect(findAllSpied).toHaveBeenCalledTimes(1);
        expect(stepLogsFromDatabase).toStrictEqual([{ consoleId: '1', stepId: 1 }]);
    });
    it('should return empty stepLogs in case of any error', async () => {
        const stepConsoleRepository = new StepConsoleRepository_1.StepConsoleRepository(1);
        const findAllSpied = jest.spyOn(StepConsoleDao_1.StepConsoleDao.prototype, 'findAll').mockRejectedValueOnce('error');
        const stepLogsFromDatabase = await stepConsoleRepository.getStepLogsByStepId(1);
        expect(findAllSpied).toHaveBeenCalledTimes(1);
        expect(stepLogsFromDatabase).toStrictEqual([]);
    });
    it('should deleteStepLogs from the database', async () => {
        const stepConsoleRepository = new StepConsoleRepository_1.StepConsoleRepository(1);
        const deleteSpied = jest.spyOn(RetryAwareStepConsoleDao_1.RetryAwareStepConsoleDao.prototype, 'delete').mockResolvedValueOnce(1);
        await stepConsoleRepository.deleteStepLogs(1);
        expect(deleteSpied).toHaveBeenCalledTimes(1);
    });
    it('should log error when step logs cannot be deleted from the database', async () => {
        const stepConsoleRepository = new StepConsoleRepository_1.StepConsoleRepository(1);
        const deleteSpied = jest.spyOn(RetryAwareStepConsoleDao_1.RetryAwareStepConsoleDao.prototype, 'delete').mockRejectedValueOnce('error');
        await stepConsoleRepository.deleteStepLogs(1);
        expect(deleteSpied).toHaveBeenCalledTimes(1);
        expect(logger.warn).toHaveBeenCalledWith("Step logs cannot be deleted due to error:'error'");
    });
});
//# sourceMappingURL=StepConsoleRepository.test.js.map