"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const logger_1 = require("@jfrog-pipelines/logger");
const FileStoreRepository_1 = require("../file-store/FileStoreRepository");
const StepConsoleRepository_1 = require("../StepConsoleRepository");
const StepConsoleRootAggregate_1 = require("../StepConsoleRootAggregate");
const StepServiceRepository_1 = require("../StepServiceRepository");
const StepletConsoleAggregate_1 = require("../StepletConsoleAggregate");
const Step_1 = require("../Step");
jest.mock('@jfrog-pipelines/configuration', () => ({
    ConfigFactory: {
        config: {
            rtUiUrl: 'http://example.com'
        }
    }
}));
jest.mock('@jfrog-pipelines/logger', () => {
    return {
        LoggerFactory: {
            getLogger: jest.fn().mockReturnValue({
                warn: jest.fn()
            })
        }
    };
});
const logger = logger_1.LoggerFactory.getLogger();
const TWO = 2;
describe('StepConsoleRootAggregate Tests', () => {
    it('should log warning if step is null', async () => {
        const stepId = 1;
        const stepConsoleRootAggregate = new StepConsoleRootAggregate_1.StepConsoleRootAggregate(stepId);
        const createSpied = jest.spyOn(Step_1.Step, 'create').mockResolvedValueOnce(null);
        await stepConsoleRootAggregate.archive(stepId);
        expect(createSpied).toHaveBeenCalledTimes(1);
        expect(createSpied).toHaveBeenCalledWith(1);
        expect(logger.warn).toHaveBeenCalledWith(`Invalid stepId received stepId: ${stepId}`);
    });
    it('should not perform archival for steplets as steplets are not available', async () => {
        const cleanTemporaryFolderSpied = jest
            .spyOn(FileStoreRepository_1.FileStoreRepository.prototype, 'cleanTempFolder')
            .mockResolvedValueOnce();
        const getStepLogsByStepIdSpied = jest
            .spyOn(StepConsoleRepository_1.StepConsoleRepository.prototype, 'getStepLogsByStepId')
            .mockResolvedValueOnce([]);
        const getStepletIdsByStepIdSpied = jest
            .spyOn(StepServiceRepository_1.StepServiceRepository.prototype, 'getStepletIdsByStepId')
            .mockResolvedValueOnce([]);
        const mockStepData = {
            id: 1,
            statusCode: 4001,
            configPropertyBag: { isExternal: false }
        };
        const archiveSpied = jest.spyOn(StepletConsoleAggregate_1.StepletConsoleAggregate.prototype, 'archive').mockResolvedValueOnce();
        const deleteStepLogsSpied = jest.spyOn(StepConsoleRepository_1.StepConsoleRepository.prototype, 'deleteStepLogs').mockResolvedValueOnce();
        const getStepByIdSpied = jest
            .spyOn(StepServiceRepository_1.StepServiceRepository.prototype, 'getStepById')
            .mockResolvedValueOnce(mockStepData);
        const isExecutionLogsNotAvaiableSpied = jest
            .spyOn(Step_1.Step.prototype, 'isExecutionLogsNotAvaiable')
            .mockReturnValueOnce(false);
        const stepConsoleRootAggregate = new StepConsoleRootAggregate_1.StepConsoleRootAggregate(1);
        await stepConsoleRootAggregate.archive(1);
        expect(cleanTemporaryFolderSpied).toHaveBeenCalledTimes(TWO);
        expect(getStepLogsByStepIdSpied).toHaveBeenCalledTimes(1);
        expect(getStepletIdsByStepIdSpied).toHaveBeenCalledTimes(1);
        expect(archiveSpied).toHaveBeenCalledTimes(0);
        expect(deleteStepLogsSpied).toHaveBeenCalledTimes(1);
        expect(getStepByIdSpied).toHaveBeenCalledTimes(1);
        expect(isExecutionLogsNotAvaiableSpied).toHaveBeenCalledTimes(1);
    });
    it('should perform archival when steplets are available', async () => {
        const cleanTemporaryFolderSpied = jest
            .spyOn(FileStoreRepository_1.FileStoreRepository.prototype, 'cleanTempFolder')
            .mockResolvedValueOnce();
        const getStepLogsByStepIdSpied = jest
            .spyOn(StepConsoleRepository_1.StepConsoleRepository.prototype, 'getStepLogsByStepId')
            .mockResolvedValueOnce([
            { consoleId: '1', stepId: 1 },
            { consoleId: '1', stepId: 1 }
        ]);
        const getStepletIdsByStepIdSpied = jest
            .spyOn(StepServiceRepository_1.StepServiceRepository.prototype, 'getStepletIdsByStepId')
            .mockResolvedValueOnce([1, TWO]);
        const archiveSpied = jest.spyOn(StepletConsoleAggregate_1.StepletConsoleAggregate.prototype, 'archive').mockResolvedValue();
        const deleteStepLogsSpied = jest.spyOn(StepConsoleRepository_1.StepConsoleRepository.prototype, 'deleteStepLogs').mockResolvedValueOnce();
        const stepConsoleRootAggregate = new StepConsoleRootAggregate_1.StepConsoleRootAggregate(1);
        const mockStepData = {
            id: 1,
            statusCode: 4001,
            configPropertyBag: {
                isExternal: false
            }
        };
        const getStepByIdSpied = jest
            .spyOn(StepServiceRepository_1.StepServiceRepository.prototype, 'getStepById')
            .mockResolvedValueOnce(mockStepData);
        const isExecutionLogsNotAvaiableSpied = jest
            .spyOn(Step_1.Step.prototype, 'isExecutionLogsNotAvaiable')
            .mockReturnValueOnce(false);
        await stepConsoleRootAggregate.archive(1);
        expect(cleanTemporaryFolderSpied).toHaveBeenCalledTimes(TWO);
        expect(getStepLogsByStepIdSpied).toHaveBeenCalledTimes(1);
        expect(getStepletIdsByStepIdSpied).toHaveBeenCalledTimes(1);
        expect(archiveSpied).toHaveBeenCalledTimes(TWO);
        expect(deleteStepLogsSpied).toHaveBeenCalledTimes(1);
        expect(getStepByIdSpied).toHaveBeenCalledTimes(1);
        expect(isExecutionLogsNotAvaiableSpied).toHaveBeenCalledTimes(1);
    });
    it('should perform archival when steplets are available with execution logs are not available', async () => {
        const cleanTemporaryFolderSpied = jest
            .spyOn(FileStoreRepository_1.FileStoreRepository.prototype, 'cleanTempFolder')
            .mockResolvedValueOnce();
        const getStepLogsByStepIdSpied = jest
            .spyOn(StepConsoleRepository_1.StepConsoleRepository.prototype, 'getStepLogsByStepId')
            .mockResolvedValueOnce([
            { consoleId: '1', stepId: 1 },
            { consoleId: '1', stepId: 1 }
        ]);
        const getStepletIdsByStepIdSpied = jest
            .spyOn(StepServiceRepository_1.StepServiceRepository.prototype, 'getStepletIdsByStepId')
            .mockResolvedValueOnce([1, TWO]);
        const archiveSpied = jest.spyOn(StepletConsoleAggregate_1.StepletConsoleAggregate.prototype, 'archive').mockResolvedValue();
        const deleteStepLogsSpied = jest.spyOn(StepConsoleRepository_1.StepConsoleRepository.prototype, 'deleteStepLogs').mockResolvedValueOnce();
        const stepConsoleRootAggregate = new StepConsoleRootAggregate_1.StepConsoleRootAggregate(1);
        const mockStepData = {
            id: 1,
            statusCode: 4008,
            configPropertyBag: {
                isExternal: true
            }
        };
        const getStepByIdSpied = jest
            .spyOn(StepServiceRepository_1.StepServiceRepository.prototype, 'getStepById')
            .mockResolvedValueOnce(mockStepData);
        const isExecutionLogsNotAvaiableSpied = jest
            .spyOn(Step_1.Step.prototype, 'isExecutionLogsNotAvaiable')
            .mockReturnValueOnce(true);
        await stepConsoleRootAggregate.archive(1);
        expect(cleanTemporaryFolderSpied).toHaveBeenCalledTimes(TWO);
        expect(getStepLogsByStepIdSpied).toHaveBeenCalledTimes(1);
        expect(getStepletIdsByStepIdSpied).toHaveBeenCalledTimes(1);
        expect(archiveSpied).toHaveBeenCalledTimes(TWO);
        expect(deleteStepLogsSpied).toHaveBeenCalledTimes(1);
        expect(getStepByIdSpied).toHaveBeenCalledTimes(1);
        expect(isExecutionLogsNotAvaiableSpied).toHaveBeenCalledTimes(1);
    });
});
//# sourceMappingURL=StepConsoleRootAggregate.test.js.map