"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const StepletConsoleAggregate_1 = require("../StepletConsoleAggregate");
const FileStoreRepository_1 = require("../file-store/FileStoreRepository");
const StepletConsoleRepository_1 = require("../StepletConsoleRepository");
const StepServiceRepository_1 = require("../StepServiceRepository");
jest.mock('@jfrog-pipelines/configuration', () => ({
    ConfigFactory: {
        config: {
            rtUiUrl: 'http://example.com'
        }
    }
}));
describe('StepletConsoleAggregate Tests', () => {
    const fileStoreRepository = new FileStoreRepository_1.FileStoreRepository(1);
    it('should be defined', () => {
        const stepletConsoleAggregate = new StepletConsoleAggregate_1.StepletConsoleAggregate(1, fileStoreRepository);
        expect(stepletConsoleAggregate).toBeDefined();
    });
    it('should archive the logs if file path is present', async () => {
        const filePathSpied = jest.spyOn(fileStoreRepository, 'createLogFile').mockResolvedValueOnce('path');
        const appendStepConsolesSpied = jest.spyOn(fileStoreRepository, 'appendStepConsoles').mockResolvedValueOnce();
        const mockedValue = new Map();
        mockedValue.set('cleanup', [
            {
                consoleId: 'wxyz',
                stepletId: 1,
                pipelineId: 1,
                isShown: true,
                isSuccess: true,
                stage: 'cleanup',
                message: 'cleanup'
            }
        ]);
        const getSetupAndCleanupLogsSpied = jest
            .spyOn(StepletConsoleRepository_1.StepletConsoleRepository.prototype, 'getSetupAndCleanupLogs')
            .mockResolvedValueOnce(mockedValue);
        const getArtifactoryUrlsByStepIdSpied = jest
            .spyOn(StepServiceRepository_1.StepServiceRepository.prototype, 'getArtifactoryUrlsByStepId')
            .mockResolvedValueOnce({});
        const stepletConsoleAggregate = new StepletConsoleAggregate_1.StepletConsoleAggregate(1, fileStoreRepository);
        const stepConsoleLogs = {
            consoleId: 'wxyz',
            stepId: 1,
            pipelineId: 1,
            isShown: true,
            isSuccess: true,
            stage: 'cleanup',
            message: 'cleanup'
        };
        const appendSetupConsolesSpied = jest
            .spyOn(FileStoreRepository_1.FileStoreRepository.prototype, 'appendSetupConsoles')
            .mockResolvedValueOnce();
        const appendExecutionLogsSpied = jest
            .spyOn(FileStoreRepository_1.FileStoreRepository.prototype, 'appendExecutionLogs')
            .mockResolvedValueOnce();
        const appendCleanupConsolesSpied = jest
            .spyOn(FileStoreRepository_1.FileStoreRepository.prototype, 'appendCleanupConsoles')
            .mockResolvedValueOnce();
        const uploadToArtifactorySpied = jest
            .spyOn(FileStoreRepository_1.FileStoreRepository.prototype, 'uploadToArtifactory')
            .mockResolvedValueOnce();
        const deleteFileSpied = jest.spyOn(FileStoreRepository_1.FileStoreRepository.prototype, 'deleteFile').mockResolvedValueOnce();
        const deleteStepletLogsSpied = jest
            .spyOn(StepletConsoleRepository_1.StepletConsoleRepository.prototype, 'deleteStepletLogs')
            .mockResolvedValueOnce();
        const markConsoleArchivedSpied = jest
            .spyOn(StepServiceRepository_1.StepServiceRepository.prototype, 'markConsoleArchived')
            .mockResolvedValueOnce();
        await stepletConsoleAggregate.archive(1, stepConsoleLogs);
        expect(filePathSpied).toHaveBeenCalledTimes(1);
        expect(appendStepConsolesSpied).toHaveBeenCalledTimes(1);
        expect(getSetupAndCleanupLogsSpied).toHaveBeenCalledTimes(1);
        expect(getArtifactoryUrlsByStepIdSpied).toHaveBeenCalledTimes(1);
        expect(appendSetupConsolesSpied).toHaveBeenCalledTimes(1);
        expect(appendExecutionLogsSpied).toHaveBeenCalledTimes(1);
        expect(appendCleanupConsolesSpied).toHaveBeenCalledTimes(1);
        expect(uploadToArtifactorySpied).toHaveBeenCalledTimes(1);
        expect(deleteFileSpied).toHaveBeenCalledTimes(1);
        expect(deleteStepletLogsSpied).toHaveBeenCalledTimes(1);
        expect(markConsoleArchivedSpied).toHaveBeenCalledTimes(1);
    });
});
//# sourceMappingURL=StepletConsoleAggregate.test.js.map