"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const logger_1 = require("@jfrog-pipelines/logger");
const StepletConsoleRepository_1 = require("../StepletConsoleRepository");
const StepletConsoleDao_1 = require("../../../driven/StepletConsoleDao");
const RetryAwareStepletConsoleDao_1 = require("../../../driven/RetryAwareStepletConsoleDao");
jest.mock('@jfrog-pipelines/logger', () => {
    const actualTracker = jest.requireActual('@jfrog-pipelines/logger');
    return {
        ...actualTracker,
        LoggerFactory: {
            getLogger: jest.fn().mockReturnValue({
                info: jest.fn(),
                error: jest.fn(),
                debug: jest.fn(),
                trace: jest.fn(),
                warn: jest.fn()
            })
        }
    };
});
const logger = logger_1.LoggerFactory.getLogger();
describe('StepletConsoleRepository tests', () => {
    it('should be defined', () => {
        const stepId = 1;
        const stepletConsoleRepository = new StepletConsoleRepository_1.StepletConsoleRepository(stepId);
        expect(stepletConsoleRepository).toBeDefined();
    });
    it('should getSetupAndCleanupLogs from the database', async () => {
        const stepletConsoleRepository = new StepletConsoleRepository_1.StepletConsoleRepository(1);
        const findAllSpied = jest.spyOn(StepletConsoleDao_1.StepletConsoleDao.prototype, 'findAll').mockResolvedValueOnce([
            {
                consoleId: 'abcd',
                stepletId: 1,
                pipelineId: 1,
                isSuccess: true,
                stage: 'setup',
                message: 'setup'
            },
            {
                consoleId: 'wxyz',
                stepletId: 1,
                pipelineId: 1,
                isSuccess: true,
                stage: 'cleanup',
                message: 'cleanup'
            }
        ]);
        const setupAndCleanupLogsFromDatabase = await stepletConsoleRepository.getSetupAndCleanupLogs(1);
        const expectedResult = new Map();
        expectedResult.set('setup', [
            {
                consoleId: 'abcd',
                stepletId: 1,
                pipelineId: 1,
                isSuccess: true,
                stage: 'setup',
                message: 'setup'
            }
        ]);
        expectedResult.set('cleanup', [
            {
                consoleId: 'wxyz',
                stepletId: 1,
                pipelineId: 1,
                isSuccess: true,
                stage: 'cleanup',
                message: 'cleanup'
            }
        ]);
        expect(findAllSpied).toHaveBeenCalledTimes(1);
        expect(setupAndCleanupLogsFromDatabase).toStrictEqual(expectedResult);
    });
    it('should return empty setupAndCleanupLogsFromDatabase in case of any error', async () => {
        const stepletConsoleRepository = new StepletConsoleRepository_1.StepletConsoleRepository(1);
        const stepletConsoleDaoSpied = jest.spyOn(StepletConsoleDao_1.StepletConsoleDao.prototype, 'findAll').mockRejectedValueOnce('error');
        const setupAndCleanupLogsFromDatabase = await stepletConsoleRepository.getSetupAndCleanupLogs(1);
        expect(stepletConsoleDaoSpied).toHaveBeenCalledTimes(1);
        const expectedResult = new Map();
        expect(setupAndCleanupLogsFromDatabase).toStrictEqual(expectedResult);
        expect(logger.warn).toHaveBeenCalledWith("Cannot get setup and clean up logs due to error:'error'");
    });
    it('should deleteStepletLogs', async () => {
        const stepletConsoleRepository = new StepletConsoleRepository_1.StepletConsoleRepository(1);
        const deleteSpied = jest.spyOn(RetryAwareStepletConsoleDao_1.RetryAwareStepletConsoleDao.prototype, 'delete').mockResolvedValueOnce(1);
        await stepletConsoleRepository.deleteStepletLogs(1);
        expect(deleteSpied).toHaveBeenCalledTimes(1);
    });
    it('should log error when step logs cannot be deleted from the database', async () => {
        const stepletConsoleRepository = new StepletConsoleRepository_1.StepletConsoleRepository(1);
        const deleteSpied = jest.spyOn(RetryAwareStepletConsoleDao_1.RetryAwareStepletConsoleDao.prototype, 'delete').mockRejectedValueOnce('error');
        await stepletConsoleRepository.deleteStepletLogs(1);
        expect(deleteSpied).toHaveBeenCalledTimes(1);
        expect(logger.warn).toHaveBeenCalledWith("Steplet logs cannot be deleted due to error:'error'");
    });
});
//# sourceMappingURL=StepletConsoleRepository.test.js.map