"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ArtifactoryFileStrategy = void 0;
const node_zlib_1 = __importDefault(require("node:zlib"));
const node_util_1 = require("node:util");
const logger_1 = require("@jfrog-pipelines/logger");
const node_uuid_1 = __importDefault(require("node-uuid"));
const ArtifactoryAdapter_1 = require("../../../driven/ArtifactoryAdapter");
const FileSystemAdapter_1 = require("../../../driven/FileSystemAdapter");
const THOUSAND = 1000;
class ArtifactoryFileStrategy {
    constructor(stepId) {
        this.logger = logger_1.LoggerFactory.getLogger('ArtifactoryFileStrategy');
        this.fileAdapter = new FileSystemAdapter_1.FileSystemAdapter(stepId);
        this.rtAdapter = new ArtifactoryAdapter_1.ArtifactoryAdapter();
    }
    async appendExecutionLogs(filePath, getUrl, token, stepletId) {
        try {
            const readStream = await this.rtAdapter.readLogFile(getUrl, token);
            const decompressor = node_zlib_1.default.createGunzip();
            const decompressedStream = readStream.pipe(decompressor);
            await this.fileAdapter.writeStreamToFile(filePath, decompressedStream);
        }
        catch (error) {
            this.logger.warn(`Cannot write steplet execution logs because of the error: ${(0, node_util_1.inspect)(error)}`);
            await this.appendFallbackExecutionLogMessage(filePath, stepletId);
        }
    }
    async appendFallbackExecutionLogMessage(filePath, stepletId) {
        const grpConsoleId = node_uuid_1.default.v4();
        const cmdConsoleId = node_uuid_1.default.v4();
        const fallbackMessage = [
            {
                stepletId: stepletId,
                consoleId: grpConsoleId,
                parentConsoleId: 'root',
                type: 'grp',
                message: 'Executing Step',
                timestamp: Date.now() * THOUSAND,
                stage: 'execution',
                isShown: true,
                isSuccess: false,
                timestampEndedAt: Date.now() * THOUSAND
            },
            {
                stepletId: stepletId,
                consoleId: cmdConsoleId,
                parentConsoleId: grpConsoleId,
                type: 'cmd',
                message: 'Unable to find execution logs',
                timestamp: Date.now() * THOUSAND,
                stage: 'execution',
                isShown: true,
                isSuccess: false,
                timestampEndedAt: Date.now() * THOUSAND
            }
        ];
        return this.fileAdapter.writeLogsToFile(filePath, fallbackMessage);
    }
}
exports.ArtifactoryFileStrategy = ArtifactoryFileStrategy;
//# sourceMappingURL=ArtifactoryFileStrategy.js.map