"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const node_zlib_1 = __importDefault(require("node:zlib"));
const node_stream_1 = require("node:stream");
const logger_1 = require("@jfrog-pipelines/logger");
const rimraf_1 = require("rimraf");
const FileSystemAdapter_1 = require("../../../../driven/FileSystemAdapter");
const ArtifactoryAdapter_1 = require("../../../../driven/ArtifactoryAdapter");
const ArtifactoryFileStrategy_1 = require("../ArtifactoryFileStrategy");
jest.mock('@jfrog-pipelines/logger', () => {
    return {
        LoggerFactory: {
            getLogger: jest.fn().mockReturnValue({
                warn: jest.fn()
            })
        }
    };
});
const logger = logger_1.LoggerFactory.getLogger();
describe('ArtifactoryFileStrategy Tests', () => {
    const stepId = 1;
    const artifactoryFileStrategy = new ArtifactoryFileStrategy_1.ArtifactoryFileStrategy(stepId);
    it('should appendExecutionLogs if no error occurs from the rtAdapter or fileAdapter', async () => {
        const data = 'hello';
        const compressedData = node_zlib_1.default.gzipSync(data);
        const mockEventStream = new node_stream_1.Readable({
            objectMode: false,
            read: function () {
                this.push(compressedData);
                this.push(null);
            }
        });
        const readStreamSpied = jest
            .spyOn(ArtifactoryAdapter_1.ArtifactoryAdapter.prototype, 'readLogFile')
            .mockResolvedValueOnce(mockEventStream);
        const writeStreamToFile = jest.spyOn(FileSystemAdapter_1.FileSystemAdapter.prototype, 'writeStreamToFile').mockResolvedValueOnce();
        const filePath = 'testPath';
        const getUrl = 'url';
        const token = 'token';
        const stepletId = 1;
        await artifactoryFileStrategy.appendExecutionLogs(filePath, getUrl, token, stepletId);
        expect(readStreamSpied).toHaveBeenCalledTimes(1);
        expect(writeStreamToFile).toHaveBeenCalledTimes(1);
    });
    it('should log warning and call appendFallbackExecutionLogMessage in case of error from rtAdapter or fileAdapter', async () => {
        jest.spyOn(ArtifactoryAdapter_1.ArtifactoryAdapter.prototype, 'readLogFile').mockRejectedValueOnce('error');
        const filePath = `${__dirname}/sample.txt`;
        const getUrl = 'url';
        const token = 'token';
        const stepletId = 1;
        await artifactoryFileStrategy.appendExecutionLogs(filePath, getUrl, token, stepletId);
        const filleSystemAdapter = new FileSystemAdapter_1.FileSystemAdapter(1);
        const fallbackMessage = [
            {
                stepletId: stepletId,
                parentConsoleId: 'root',
                type: 'grp',
                message: 'Executing Step',
                stage: 'execution',
                isShown: true,
                isSuccess: false
            },
            {
                stepletId: stepletId,
                type: 'cmd',
                message: 'Unable to find execution logs',
                stage: 'execution',
                isShown: true,
                isSuccess: false
            }
        ];
        const areLogsWritten = await filleSystemAdapter.writeLogsToFile(filePath, fallbackMessage);
        expect(areLogsWritten).toStrictEqual(true);
        expect(logger.warn).toHaveBeenCalledWith("Cannot write steplet execution logs because of the error: 'error'");
        (0, rimraf_1.sync)(filePath);
    });
});
//# sourceMappingURL=ArtifactoryFileStrategy.test.js.map