"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const logger_1 = require("@jfrog-pipelines/logger");
const StepConsoleDao_1 = require("../../../driven/StepConsoleDao");
const InsertRepository_1 = require("../InsertRepository");
const StepletConsoleDao_1 = require("../../../driven/StepletConsoleDao");
jest.mock('@jfrog-pipelines/logger', () => {
    return {
        LoggerFactory: {
            getLogger: jest.fn().mockReturnValue({
                warn: jest.fn()
            })
        }
    };
});
const logger = logger_1.LoggerFactory.getLogger();
describe('InsertRepository Tests', () => {
    const insertRepository = new InsertRepository_1.InsertRepository();
    it("should save the stepLogs in the database if the objectType is 'step'", async () => {
        const objectType = 'step';
        const consoleObjects = [
            {
                consoleId: 'test',
                pipelineId: 1
            }
        ];
        const stepConsoleDaoSpied = jest
            .spyOn(StepConsoleDao_1.StepConsoleDao.prototype, 'createBulk')
            .mockResolvedValueOnce({});
        await insertRepository.save(objectType, consoleObjects);
        expect(stepConsoleDaoSpied).toHaveBeenCalledWith([{ consoleId: 'test', pipelineId: 1 }]);
        expect(stepConsoleDaoSpied).toHaveBeenCalledTimes(1);
    });
    it("should save the multiple stepLogs  in the database if the objectType is 'step'", async () => {
        const objectType = 'step';
        const consoleObjects = [
            {
                consoleId: 'test',
                stepId: 1,
                pipelineId: 1,
                isSuccess: true,
                isShown: true,
                parentConsoleId: 'testParent',
                stage: 'setup',
                timestamp: 1,
                message: 'testMessage',
                type: 'test',
                timestampEndedAt: 1
            },
            {
                consoleId: 'test',
                stepId: 2,
                pipelineId: 2,
                isSuccess: true,
                isShown: true,
                parentConsoleId: 'testParent',
                stage: 'setup',
                timestamp: 2,
                message: 'testMessage',
                type: 'test',
                timestampEndedAt: 2
            }
        ];
        const stepConsoleDaoSpied = jest
            .spyOn(StepConsoleDao_1.StepConsoleDao.prototype, 'createBulk')
            .mockResolvedValueOnce({});
        await insertRepository.save(objectType, consoleObjects);
        const expectedResult = [
            {
                consoleId: 'test',
                isShown: true,
                isSuccess: true,
                message: 'testMessage',
                parentConsoleId: 'testParent',
                pipelineId: 1,
                stage: 'setup',
                stepId: 1,
                timestamp: 1,
                timestampEndedAt: 1,
                type: 'test'
            },
            {
                consoleId: 'test',
                isShown: true,
                isSuccess: true,
                message: 'testMessage',
                parentConsoleId: 'testParent',
                pipelineId: 2,
                stage: 'setup',
                stepId: 2,
                timestamp: 2,
                timestampEndedAt: 2,
                type: 'test'
            }
        ];
        expect(stepConsoleDaoSpied).toHaveBeenCalledWith(expectedResult);
        expect(stepConsoleDaoSpied).toHaveBeenCalledTimes(1);
    });
    it('should log warning if logs cannot be saved to the databasecdue to some error', async () => {
        const objectType = 'steplet';
        const consoleObjects = [
            {
                consoleId: 'test',
                pipelineId: 1
            }
        ];
        const stepConsoleDaoSpied = jest.spyOn(StepletConsoleDao_1.StepletConsoleDao.prototype, 'createBulk').mockRejectedValueOnce('error');
        await insertRepository.save(objectType, consoleObjects);
        expect(stepConsoleDaoSpied).toHaveBeenCalledTimes(1);
        expect(logger.warn).toHaveBeenCalledWith("Cannot create InsertRepository logs for steplet of type: { consoleId: 'test', pipelineId: 1 }with 'error'");
    });
    it("should save the stepletLogs in the database if the objectType is 'steplet'", async () => {
        const objectType = 'steplet';
        const consoleObjects = [
            {
                consoleId: 'test',
                pipelineId: 1
            }
        ];
        const stepConsoleDaoSpied = jest
            .spyOn(StepletConsoleDao_1.StepletConsoleDao.prototype, 'createBulk')
            .mockResolvedValueOnce({});
        await insertRepository.save(objectType, consoleObjects);
        expect(stepConsoleDaoSpied).toHaveBeenCalledTimes(1);
        expect(stepConsoleDaoSpied).toHaveBeenCalledWith([{ consoleId: 'test', pipelineId: 1 }]);
    });
    it('should return if consoleObjects (logs) are empty', async () => {
        const objectType = 'steplet';
        const consoleObjects = [];
        const stepConsoleDaoSpied = jest
            .spyOn(StepletConsoleDao_1.StepletConsoleDao.prototype, 'createBulk')
            .mockResolvedValueOnce({});
        await insertRepository.save(objectType, consoleObjects);
        expect(stepConsoleDaoSpied).toHaveBeenCalledTimes(0);
    });
});
//# sourceMappingURL=InsertRepository.test.js.map