"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const InsertRepository_1 = require("../InsertRepository");
const WebConsoleCollection_1 = require("../WebConsoleCollection");
describe('WebConsoleCollection Tests', () => {
    it('should call the save method and insert the logs when objectType is step to the database and stage is setup and type is cmd', async () => {
        const objectType = 'step';
        const consoleObjects = [
            {
                consoleId: 'test',
                pipelineId: 1,
                stage: 'setup',
                type: 'cmd'
            }
        ];
        const webConsoleCollection = new WebConsoleCollection_1.WebConsoleCollection(objectType, consoleObjects);
        const insertRepositorySpied = jest.spyOn(InsertRepository_1.InsertRepository.prototype, 'save').mockResolvedValueOnce();
        await webConsoleCollection.save();
        expect(insertRepositorySpied).toHaveBeenCalledTimes(1);
        const mockExpectedResult = [
            {
                consoleId: 'test',
                pipelineId: 1,
                stage: 'setup',
                type: 'cmd'
            }
        ];
        expect(insertRepositorySpied).toHaveBeenCalledWith('step', mockExpectedResult);
    });
    it('should call the save method and insert the logs when objectType is step to the database and stage is execution and type is group', async () => {
        const objectType = 'step';
        const consoleObjects = [
            {
                consoleId: 'test',
                pipelineId: 1,
                stage: 'execution',
                type: 'group'
            }
        ];
        const webConsoleCollection = new WebConsoleCollection_1.WebConsoleCollection(objectType, consoleObjects);
        const insertRepositorySpied = jest.spyOn(InsertRepository_1.InsertRepository.prototype, 'save').mockResolvedValueOnce();
        await webConsoleCollection.save();
        expect(insertRepositorySpied).toHaveBeenCalledTimes(1);
        const mockExpectedResult = [
            {
                consoleId: 'test',
                pipelineId: 1,
                stage: 'execution',
                type: 'group'
            }
        ];
        expect(insertRepositorySpied).toHaveBeenCalledWith('step', mockExpectedResult);
    });
    it('should call the save method and insert the logs when objectType is step to the database and stage is cleanup and type is msg', async () => {
        const objectType = 'step';
        const consoleObjects = [
            {
                consoleId: 'test',
                pipelineId: 1,
                stage: 'cleanup',
                type: 'msg'
            }
        ];
        const webConsoleCollection = new WebConsoleCollection_1.WebConsoleCollection(objectType, consoleObjects);
        const insertRepositorySpied = jest.spyOn(InsertRepository_1.InsertRepository.prototype, 'save').mockResolvedValueOnce();
        await webConsoleCollection.save();
        expect(insertRepositorySpied).toHaveBeenCalledTimes(1);
        const mockExpectedResult = [
            {
                consoleId: 'test',
                pipelineId: 1,
                stage: 'cleanup',
                type: 'msg'
            }
        ];
        expect(insertRepositorySpied).toHaveBeenCalledWith('step', mockExpectedResult);
    });
    it('should call the save method of insertRepository to insert the logs in the database when objectType is steplet and stage is setup and type is cmd', async () => {
        const objectType = 'steplet';
        const consoleObjects = [
            {
                consoleId: 'test',
                pipelineId: 1,
                stage: 'setup',
                type: 'cmd'
            }
        ];
        const webConsoleCollection = new WebConsoleCollection_1.WebConsoleCollection(objectType, consoleObjects);
        const insertRepositorySpied = jest.spyOn(InsertRepository_1.InsertRepository.prototype, 'save').mockResolvedValueOnce();
        await webConsoleCollection.save();
        const mockExpectedResult = [{ consoleId: 'test', pipelineId: 1, stage: 'setup', type: 'cmd' }];
        expect(insertRepositorySpied).toHaveBeenCalledTimes(1);
        expect(insertRepositorySpied).toHaveBeenCalledWith('steplet', mockExpectedResult);
    });
    it('should call the save method and insert the logs when objectType is steplet to the database and stage is execution and type is group', async () => {
        const objectType = 'steplet';
        const consoleObjects = [
            {
                consoleId: 'test',
                pipelineId: 1,
                stage: 'execution',
                type: 'group'
            }
        ];
        const webConsoleCollection = new WebConsoleCollection_1.WebConsoleCollection(objectType, consoleObjects);
        const insertRepositorySpied = jest.spyOn(InsertRepository_1.InsertRepository.prototype, 'save').mockResolvedValueOnce();
        await webConsoleCollection.save();
        expect(insertRepositorySpied).toHaveBeenCalledTimes(1);
        const mockExpectedResult = [
            {
                consoleId: 'test',
                pipelineId: 1,
                stage: 'execution',
                type: 'group'
            }
        ];
        expect(insertRepositorySpied).toHaveBeenCalledWith('steplet', mockExpectedResult);
    });
    it('should call the save method and insert the logs when objectType is steplet to the database and stage is cleanup and type is msg', async () => {
        const objectType = 'steplet';
        const consoleObjects = [
            {
                consoleId: 'test',
                pipelineId: 1,
                stage: 'cleanup',
                type: 'msg'
            }
        ];
        const webConsoleCollection = new WebConsoleCollection_1.WebConsoleCollection(objectType, consoleObjects);
        const insertRepositorySpied = jest.spyOn(InsertRepository_1.InsertRepository.prototype, 'save').mockResolvedValueOnce();
        await webConsoleCollection.save();
        expect(insertRepositorySpied).toHaveBeenCalledTimes(1);
        const mockExpectedResult = [
            {
                consoleId: 'test',
                pipelineId: 1,
                stage: 'cleanup',
                type: 'msg'
            }
        ];
        expect(insertRepositorySpied).toHaveBeenCalledWith('steplet', mockExpectedResult);
    });
    it('should call the save method and insert the logs when objectType is steplet to the database and stage is cleanup and type is msg and timestampEndedAt is null', async () => {
        const objectType = 'steplet';
        const consoleObjects = [
            {
                consoleId: 'test',
                pipelineId: 1,
                stage: 'cleanup',
                type: 'msg',
                timestampEndedAt: null
            }
        ];
        const webConsoleCollection = new WebConsoleCollection_1.WebConsoleCollection(objectType, consoleObjects);
        const insertRepositorySpied = jest.spyOn(InsertRepository_1.InsertRepository.prototype, 'save').mockResolvedValueOnce();
        await webConsoleCollection.save();
        expect(insertRepositorySpied).toHaveBeenCalledTimes(1);
        const mockExpectedResult = [
            {
                consoleId: 'test',
                pipelineId: 1,
                stage: 'cleanup',
                type: 'msg',
                timestampEndedAt: null
            }
        ];
        expect(insertRepositorySpied).toHaveBeenCalledWith('steplet', mockExpectedResult);
    });
    it('should call the save method and insert an array of logs when objectType is steplet to the database and stage is cleanup and type is msg', async () => {
        const objectType = 'steplet';
        const consoleObjects = [
            {
                consoleId: 'test',
                pipelineId: 1,
                stage: 'setup',
                type: 'msg'
            },
            {
                consoleId: 'test',
                pipelineId: 1,
                stage: 'execution',
                type: 'msg'
            },
            {
                consoleId: 'test',
                pipelineId: 1,
                stage: 'cleanup',
                type: 'msg'
            }
        ];
        const webConsoleCollection = new WebConsoleCollection_1.WebConsoleCollection(objectType, consoleObjects);
        const insertRepositorySpied = jest.spyOn(InsertRepository_1.InsertRepository.prototype, 'save').mockResolvedValueOnce();
        await webConsoleCollection.save();
        expect(insertRepositorySpied).toHaveBeenCalledTimes(1);
        const mockExpectedResult = [
            {
                consoleId: 'test',
                pipelineId: 1,
                stage: 'setup',
                type: 'msg'
            },
            {
                consoleId: 'test',
                pipelineId: 1,
                stage: 'execution',
                type: 'msg'
            },
            {
                consoleId: 'test',
                pipelineId: 1,
                stage: 'cleanup',
                type: 'msg'
            }
        ];
        expect(insertRepositorySpied).toHaveBeenCalledWith('steplet', mockExpectedResult);
    });
});
//# sourceMappingURL=WebConsoleCollection.test.js.map