"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FileSystemAdapter = void 0;
const promises_1 = __importDefault(require("node:fs/promises"));
const node_fs_1 = require("node:fs");
const node_path_1 = __importDefault(require("node:path"));
const node_util_1 = require("node:util");
const node_os_1 = __importDefault(require("node:os"));
const node_assert_1 = require("node:assert");
const logger_1 = require("@jfrog-pipelines/logger");
class FileSystemAdapter {
    constructor(stepId) {
        this.stepId = stepId;
        this.logger = logger_1.LoggerFactory.getLogger(`FileSystemAdapter:${this.stepId}`);
    }
    async createFile(stepletId) {
        const folderPath = node_os_1.default.tmpdir();
        const fileName = `${stepletId}_log.txt`;
        const destinationPath = node_path_1.default.join(folderPath, fileName);
        try {
            await promises_1.default.open(destinationPath, 'a');
            this.logger.debug(`${destinationPath} file created`);
            return destinationPath;
        }
        catch {
            this.logger.warn(`Cannot create ${destinationPath}`);
            return null;
        }
    }
    async deleteFile(filePath) {
        try {
            await promises_1.default.unlink(filePath);
            this.logger.debug(`${filePath} deleted successfully`);
        }
        catch (error) {
            this.logger.warn(`Deleting ${filePath} failed with error:${error}`);
        }
    }
    async writeLogsToFile(filePath, logs) {
        return new Promise((resolve, reject) => {
            if (!filePath) {
                reject(new node_assert_1.AssertionError({ message: 'No valid file path exists' }));
            }
            const writeStream = (0, node_fs_1.createWriteStream)(filePath, { flags: 'a' });
            for (const log of logs) {
                writeStream.write(`${JSON.stringify(log)}\n`);
            }
            writeStream.end();
            writeStream.on('finish', () => {
                resolve(true);
            });
            writeStream.on('error', (error) => {
                this.logger.warn(`Failed to write to ${filePath}, error: ${(0, node_util_1.inspect)(error)}`);
                reject(error);
            });
        });
    }
    async clearTempFolder() {
        const folderPath = node_os_1.default.tmpdir();
        const files = await promises_1.default.readdir(folderPath);
        for (const file of files) {
            const filePath = node_path_1.default.join(folderPath, file);
            const isFile = (await promises_1.default.stat(filePath)).isFile();
            if (isFile) {
                await promises_1.default.unlink(filePath);
            }
        }
    }
    async writeStreamToFile(filePath, inputStream) {
        return new Promise((resolve, reject) => {
            const fileWriteStream = (0, node_fs_1.createWriteStream)(filePath, { flags: 'a' });
            inputStream.pipe(fileWriteStream);
            fileWriteStream.on('finish', resolve);
            fileWriteStream.on('error', reject);
        });
    }
    getReadStream(filePath) {
        return (0, node_fs_1.createReadStream)(filePath);
    }
}
exports.FileSystemAdapter = FileSystemAdapter;
//# sourceMappingURL=FileSystemAdapter.js.map