"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const logger_1 = require("@jfrog-pipelines/logger");
const axios_1 = __importDefault(require("axios"));
const ArtifactoryAdapter_1 = require("../ArtifactoryAdapter");
jest.mock('@jfrog-pipelines/logger', () => {
    const actualTracker = jest.requireActual('@jfrog-pipelines/logger');
    return {
        ...actualTracker,
        LoggerFactory: {
            getLogger: jest.fn().mockReturnValue({
                info: jest.fn(),
                error: jest.fn(),
                debug: jest.fn(),
                trace: jest.fn(),
                warn: jest.fn()
            })
        }
    };
});
const logger = logger_1.LoggerFactory.getLogger();
jest.mock('axios');
axios_1.default.mockImplementation(() => {
    return {
        data: 'hello',
        status: 200
    };
});
const TWO_HUNDRED = 200;
describe('ArtifactoryAdapter', () => {
    const artifactoryAdapter = new ArtifactoryAdapter_1.ArtifactoryAdapter();
    it('should successfully read a log file', async () => {
        const getUrl = 'https://example.com/log.txt';
        const token = 'mocked-token';
        const result = await artifactoryAdapter.readLogFile(getUrl, token);
        expect(result).toStrictEqual('hello');
    });
    it('should successfully check a log file', async () => {
        const getUrl = 'https://example.com/log.txt';
        const token = 'mocked-token';
        const result = (await artifactoryAdapter.checkLogFile(getUrl, token));
        expect(result.status).toBe(TWO_HUNDRED);
    });
    it('should successfully upload a log file', async () => {
        const axiosSpy = jest.spyOn(axios_1.default, 'put');
        axiosSpy.mockResolvedValue({});
        const inputStream = 'MockedReadableStream';
        const putUrl = 'https://example.com/upload.txt';
        const token = 'mocked-token';
        await artifactoryAdapter.upload(inputStream, putUrl, token);
        expect(logger.debug).toHaveBeenCalledWith('Uploaded to Artifactory completed');
    });
});
//# sourceMappingURL=ArtifactoryAdapter.test.js.map