"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const internal_clients_1 = require("@jfrog-pipelines/internal-clients");
const StepServiceDataAdapter_1 = require("../acl/step-service/StepServiceDataAdapter");
jest.mock('@jfrog-pipelines/configuration', () => ({
    ConfigFactory: {
        config: {
            rtUiUrl: 'http://example.com'
        }
    }
}));
describe('StepServiceDataAdapter Tests', () => {
    const stepServiceDataAdapter = new StepServiceDataAdapter_1.StepServiceDataAdapter();
    it('should be defined', () => {
        expect(stepServiceDataAdapter).toBeDefined();
    });
    it('should return artifact urls', async () => {
        const getArtifactUrlByStepIdSpied = jest
            .spyOn(internal_clients_1.PipelinesClient.prototype, 'getArtifactUrlByStepId')
            .mockResolvedValueOnce({ '1': 'artifactName' });
        const stepId = 1;
        const artifactName = 'artifactName';
        await stepServiceDataAdapter.getArtifactoryUrlByStepId(stepId, artifactName);
        expect(getArtifactUrlByStepIdSpied).toHaveBeenCalledTimes(1);
    });
    it('should getStepletsByStepId from the pipelinesClient', async () => {
        const getStepletsSpied = jest.spyOn(internal_clients_1.PipelinesClient.prototype, 'getSteplets').mockResolvedValueOnce(1);
        await stepServiceDataAdapter.getStepletsByStepId(1);
        expect(getStepletsSpied).toHaveBeenCalledTimes(1);
    });
    it('should updateConsoleArchived from the pipelinesClient', async () => {
        const putStepletByIdSpied = jest.spyOn(internal_clients_1.PipelinesClient.prototype, 'putStepletById').mockResolvedValueOnce(1);
        await stepServiceDataAdapter.updateConsoleArchived(1);
        expect(putStepletByIdSpied).toHaveBeenCalledTimes(1);
    });
    it('should get step by id from the pipelinesClient', async () => {
        const mockStep = {
            id: 1,
            pipelineId: 1,
            pipelineStepId: 1,
            name: 'step',
            runId: 1
        };
        const getStepByIdSpied = jest.spyOn(internal_clients_1.PipelinesClient.prototype, 'getStepById').mockResolvedValueOnce(mockStep);
        await stepServiceDataAdapter.getStepById(1);
        expect(getStepByIdSpied).toHaveBeenCalledTimes(1);
        expect(getStepByIdSpied).toHaveBeenCalledWith(1);
    });
});
//# sourceMappingURL=StepServiceDataAdapter.test.js.map