"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WebConsoleCreateCommand = exports.STEPLET = exports.STEP = void 0;
const node_assert_1 = require("node:assert");
const node_util_1 = require("node:util");
const utility_1 = require("@jfrog-pipelines/utility");
const logger_1 = require("@jfrog-pipelines/logger");
exports.STEP = 'step';
exports.STEPLET = 'steplet';
const SETUP = 'setup';
const EXECUTION = 'execution';
const CLEANUP = 'cleanup';
const CMD = 'cmd';
const GROUP = 'grp';
const MSG = 'msg';
class WebConsoleCreateCommand {
    constructor(payload) {
        this.payload = payload;
        this.logger = logger_1.LoggerFactory.getLogger(`InsertRepository`);
    }
    validate() {
        this.validateObjectId();
        this.validateObjectType();
        const consoles = this.getConsoleObjects();
        if ((0, utility_1.isEmpty)(consoles)) {
            return;
        }
        this.validateStage(consoles);
        this.validateType(consoles);
    }
    getId() {
        return this.payload.objectId;
    }
    getObjectType() {
        return this.payload.objectType;
    }
    getConsoleObjects() {
        return this.payload.consoles ?? [];
    }
    validateObjectId() {
        if (!this.payload.objectId || !(typeof this.payload.objectId === 'number')) {
            throw new node_assert_1.AssertionError({
                message: `Invalid objectId received. Expected a number, received ${this.payload.objectId}`
            });
        }
    }
    validateObjectType() {
        if (!this.payload.objectType || !(this.payload.objectType === exports.STEP || this.payload.objectType === exports.STEPLET)) {
            this.payload.objectType = exports.STEP;
            this.logger.warn(`Invalid objectType received ${(0, node_util_1.inspect)(this.payload.objectType)}, setting objectType as default 'step' `);
        }
    }
    validateStage(consoles) {
        const validStages = new Set([SETUP, EXECUTION, CLEANUP]);
        for (const console of consoles) {
            if (!validStages.has(console.stage)) {
                console.stage = EXECUTION;
                this.logger.warn(`Cannot get stage for the consoles, setting stage as default 'execution'`);
            }
        }
    }
    validateType(consoles) {
        const validTypes = new Set([CMD, GROUP, MSG]);
        for (const console of consoles) {
            if (!validTypes.has(console.type)) {
                console.type = MSG;
                this.logger.warn(`Cannot get type for the consoles, setting type as default 'msg'`);
            }
        }
    }
}
exports.WebConsoleCreateCommand = WebConsoleCreateCommand;
//# sourceMappingURL=WebConsoleCreateCommand.js.map