"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const WebConsoleArchivalCommand_1 = require("../WebConsoleArchivalCommand");
describe('WebConsoleArchivalCommand Tests', () => {
    it("should throw error if payload 's objectId is 'undefined'", () => {
        const payload = {
            objectId: undefined,
            objectType: 'step',
            message: 'test'
        };
        const webConsoleArchivalCommand = new WebConsoleArchivalCommand_1.WebConsoleArchivalCommand(payload);
        expect(() => {
            webConsoleArchivalCommand.validate();
        }).toThrow('Invalid objectId received. Expected a number, received undefined');
    });
    it("should throw error if payload's objectId is not a number", () => {
        const payload = {
            objectId: 'string',
            objectType: 'step',
            message: 'test'
        };
        const webConsoleArchivalCommand = new WebConsoleArchivalCommand_1.WebConsoleArchivalCommand(payload);
        expect(() => {
            webConsoleArchivalCommand.validate();
        }).toThrow('Invalid objectId received. Expected a number, received string');
    });
    it("should throw error if payload 's objectType is undefined", () => {
        const payload = {
            objectId: 1,
            objectType: undefined,
            message: 'test'
        };
        const webConsoleArchivalCommand = new WebConsoleArchivalCommand_1.WebConsoleArchivalCommand(payload);
        expect(() => {
            webConsoleArchivalCommand.validate();
        }).toThrow("Invalid objectType received. Expected either 'step' or 'steplet', received");
    });
    it("should throw error if payload 's objectType is not a step", () => {
        const payload = {
            objectId: 1,
            objectType: 'test',
            message: 'test'
        };
        const webConsoleArchivalCommand = new WebConsoleArchivalCommand_1.WebConsoleArchivalCommand(payload);
        expect(() => {
            webConsoleArchivalCommand.validate();
        }).toThrow("Invalid objectType received. Expected either 'step' or 'steplet', received");
    });
    it('should return stepId/stepletId', () => {
        const payload = { objectId: 1, objectType: 'step', message: 'test' };
        const webConsoleArchivalCommand = new WebConsoleArchivalCommand_1.WebConsoleArchivalCommand(payload);
        const objectId = webConsoleArchivalCommand.getStepId();
        expect(objectId).toStrictEqual(1);
    });
    it('should return objectType', () => {
        const payload = { objectId: 1, objectType: 'step', message: 'test' };
        const webConsoleArchivalCommand = new WebConsoleArchivalCommand_1.WebConsoleArchivalCommand(payload);
        const objectType = webConsoleArchivalCommand.getObjectType();
        expect(objectType).toStrictEqual('step');
    });
});
//# sourceMappingURL=WebConsoleArchivalCommand.test.js.map