"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const logger_1 = require("@jfrog-pipelines/logger");
const WebConsoleCreateCommand_1 = require("../WebConsoleCreateCommand");
jest.mock('@jfrog-pipelines/logger', () => {
    return {
        LoggerFactory: {
            getLogger: jest.fn().mockReturnValue({
                warn: jest.fn()
            })
        }
    };
});
const logger = logger_1.LoggerFactory.getLogger();
describe('WebConsoleCreateCommand Tests', () => {
    it('should validate objectId and objectType', () => {
        const payload = {
            objectId: 1,
            objectType: 'step',
            consoles: [
                {
                    pipleineId: 1,
                    consoleId: 'test'
                }
            ]
        };
        const webConsoleCreateCommand = new WebConsoleCreateCommand_1.WebConsoleCreateCommand(payload);
        webConsoleCreateCommand.validate();
        expect(webConsoleCreateCommand).toBeDefined();
    });
    it('should throw error if  objectId is invalid', () => {
        const payload = {
            objectId: '1',
            objectType: 'step',
            consoles: [
                {
                    pipleineId: 1,
                    consoleId: 'test'
                }
            ]
        };
        const webConsoleCreateCommand = new WebConsoleCreateCommand_1.WebConsoleCreateCommand(payload);
        expect(() => {
            webConsoleCreateCommand.validate();
        }).toThrow('Invalid objectId received. Expected a number, received 1');
    });
    it('should set objectType as step if objectType is invalid', () => {
        const payload = {
            objectId: 1,
            objectType: 'testToErrorOut',
            consoles: [
                {
                    pipleineId: 1,
                    consoleId: 'test',
                    stage: 'execution',
                    type: 'msg'
                }
            ]
        };
        const webConsoleCreateCommand = new WebConsoleCreateCommand_1.WebConsoleCreateCommand(payload);
        webConsoleCreateCommand.validate();
        expect(logger.warn).toHaveBeenCalledTimes(1);
        expect(logger.warn).toHaveBeenCalledWith("Invalid objectType received 'step', setting objectType as default 'step' ");
    });
    it('should get objectId', () => {
        const payload = {
            objectId: 1,
            objectType: 'step',
            consoles: [
                {
                    pipleineId: 1,
                    consoleId: 'test'
                }
            ]
        };
        const webConsoleCreateCommand = new WebConsoleCreateCommand_1.WebConsoleCreateCommand(payload);
        const result = webConsoleCreateCommand.getId();
        expect(result).toStrictEqual(payload.objectId);
    });
    it('should get getObjectType', () => {
        const payload = {
            objectId: 1,
            objectType: 'step',
            consoles: [
                {
                    pipleineId: 1,
                    consoleId: 'test'
                }
            ]
        };
        const webConsoleCreateCommand = new WebConsoleCreateCommand_1.WebConsoleCreateCommand(payload);
        const result = webConsoleCreateCommand.getObjectType();
        expect(result).toStrictEqual(payload.objectType);
    });
    it('should get getConsoleObjects', () => {
        const payload = {
            objectId: 1,
            objectType: 'step',
            consoles: [
                {
                    pipleineId: 1,
                    consoleId: 'test'
                }
            ]
        };
        const webConsoleCreateCommand = new WebConsoleCreateCommand_1.WebConsoleCreateCommand(payload);
        const result = webConsoleCreateCommand.getConsoleObjects();
        expect(result).toStrictEqual(payload.consoles);
    });
    it('getConsoleObjects should return empty consoles if consoles are undefined', () => {
        const payload = {
            objectId: 1,
            objectType: 'step',
            consoles: undefined
        };
        const webConsoleCreateCommand = new WebConsoleCreateCommand_1.WebConsoleCreateCommand(payload);
        const result = webConsoleCreateCommand.getConsoleObjects();
        expect(result).toStrictEqual([]);
    });
    it('should set stage as execution if stage is invalid', () => {
        const payload = {
            objectId: 1,
            objectType: 'step',
            consoles: [
                {
                    pipleineId: 1,
                    consoleId: 'test',
                    stage: 'test',
                    type: 'msg'
                }
            ]
        };
        const webConsoleCreateCommand = new WebConsoleCreateCommand_1.WebConsoleCreateCommand(payload);
        webConsoleCreateCommand.validate();
        expect(logger.warn).toHaveBeenCalledTimes(1);
        expect(logger.warn).toHaveBeenCalledWith("Cannot get stage for the consoles, setting stage as default 'execution'");
    });
    it('should set type as msg if type is invalid', () => {
        const payload = {
            objectId: 1,
            objectType: 'step',
            consoles: [
                {
                    pipleineId: 1,
                    consoleId: 'test',
                    stage: 'setup',
                    type: 'error'
                }
            ]
        };
        const webConsoleCreateCommand = new WebConsoleCreateCommand_1.WebConsoleCreateCommand(payload);
        webConsoleCreateCommand.validate();
        expect(logger.warn).toHaveBeenCalledTimes(1);
        expect(logger.warn).toHaveBeenCalledWith("Cannot get type for the consoles, setting type as default 'msg'");
    });
    it('should validate only objectId and objectType and not validate stage and type if consoles are empty', () => {
        const payload = {
            objectId: 1,
            objectType: 'error',
            consoles: []
        };
        const webConsoleCreateCommand = new WebConsoleCreateCommand_1.WebConsoleCreateCommand(payload);
        webConsoleCreateCommand.validate();
        expect(logger.warn).toHaveBeenCalledTimes(1);
        expect(logger.warn).toHaveBeenCalledWith(`Invalid objectType received '${payload.objectType}', setting objectType as default 'step' `);
    });
});
//# sourceMappingURL=WebConsoleCreateCommand.test.js.map