"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WebConsoleCreateHandler = void 0;
const node_util_1 = require("node:util");
const logger_1 = require("@jfrog-pipelines/logger");
const WebConsoleCollection_1 = require("../domain/insertion/WebConsoleCollection");
const THOUSAND = 1000;
var Identifiers;
(function (Identifiers) {
    Identifiers["step"] = "stepId";
    Identifiers["steplet"] = "stepletId";
})(Identifiers || (Identifiers = {}));
class WebConsoleCreateHandler {
    constructor(command) {
        this.command = command;
        this.logger = logger_1.LoggerFactory.getLogger('WebConsoleCreateCommandHandler');
    }
    async handle() {
        try {
            const consoleObjects = this.command.getConsoleObjects();
            const objectId = this.command.getId();
            const objectType = this.command.getObjectType();
            const webConsoleObjects = this.createWebConsoleObject(objectId, objectType, consoleObjects);
            const webConsole = new WebConsoleCollection_1.WebConsoleCollection(objectType, webConsoleObjects);
            await webConsole.save();
        }
        catch (error) {
            this.logger.warn(`Unable to insert console logs with ${(0, node_util_1.inspect)(error)}`);
        }
    }
    createWebConsoleObject(objectId, objectType, consoleObjects) {
        if (consoleObjects.length === 0) {
            return [];
        }
        const webConsoles = [];
        const identifiers = this.getIdentifier(objectType);
        for (const consoleObject of consoleObjects) {
            webConsoles.push({
                [identifiers]: objectId,
                consoleId: consoleObject.consoleId,
                pipelineId: consoleObject.pipelineId,
                isSuccess: consoleObject.isSuccess,
                isShown: consoleObject.isShown,
                parentConsoleId: consoleObject.parentConsoleId,
                stage: consoleObject.stage,
                timestamp: consoleObject.timestamp,
                timestampEndedAt: this.getTimeStampEndedAt(objectType, consoleObject.timestampEndedAt),
                type: consoleObject.type,
                message: consoleObject.message
            });
        }
        return webConsoles;
    }
    getTimeStampEndedAt(objectType, timestampEndedAt) {
        if (objectType === 'steplet' && !timestampEndedAt) {
            return Date.now() * THOUSAND;
        }
        return timestampEndedAt ?? undefined;
    }
    getIdentifier(objectType) {
        return objectType === 'step' ? 'stepId' : 'stepletId';
    }
}
exports.WebConsoleCreateHandler = WebConsoleCreateHandler;
//# sourceMappingURL=WebConsoleCreateHandler.js.map