"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const WebConsoleArchivalCommand_1 = require("../../driving/command/WebConsoleArchivalCommand");
const WebConsoleArchivalHandler_1 = require("../WebConsoleArchivalHandler");
const StepConsoleRootAggregate_1 = require("../../domain/archival/StepConsoleRootAggregate");
jest.mock('@jfrog-pipelines/configuration', () => ({
    ConfigFactory: {
        config: {
            rtUiUrl: 'http://example.com'
        }
    }
}));
describe('WebConsoleArchivalHandler Tests', () => {
    it('should be defined', () => {
        const payload = { objectId: 1, objectType: 'step' };
        const archivalCommand = new WebConsoleArchivalCommand_1.WebConsoleArchivalCommand(payload);
        const webConsoleArchivalHandler = new WebConsoleArchivalHandler_1.WebConsoleArchivalHandler(archivalCommand);
        const expectedArchivalCommand = {
            payload: { objectId: 1, objectType: 'step' }
        };
        expect(archivalCommand).toEqual(expectedArchivalCommand);
        expect(webConsoleArchivalHandler).toBeDefined();
    });
    it('should get stepIds from webConsoleArchivalCommand', () => {
        const payload = { objectId: 1, objectType: 'step' };
        const webConsoleArchivalCommand = new WebConsoleArchivalCommand_1.WebConsoleArchivalCommand(payload);
        const stepId = webConsoleArchivalCommand.getStepId();
        expect(stepId).toStrictEqual(payload.objectId);
    });
    it('should call the stepConsoleRootAggregate', async () => {
        const getStepIdSpied = jest.spyOn(WebConsoleArchivalCommand_1.WebConsoleArchivalCommand.prototype, 'getStepId').mockReturnValueOnce(1);
        const archivedSpied = jest.spyOn(StepConsoleRootAggregate_1.StepConsoleRootAggregate.prototype, 'archive').mockResolvedValueOnce();
        const payload = { objectId: 1, objectType: 'step' };
        const webConsoleArchivalHandler = new WebConsoleArchivalHandler_1.WebConsoleArchivalHandler(new WebConsoleArchivalCommand_1.WebConsoleArchivalCommand(payload));
        await webConsoleArchivalHandler.handle();
        expect(getStepIdSpied).toHaveBeenCalledTimes(1);
        expect(archivedSpied).toHaveBeenCalledTimes(1);
    });
});
//# sourceMappingURL=WebConsoleArchivalHandler.test.js.map