"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const logger_1 = require("@jfrog-pipelines/logger");
const WebConsoleCreateCommand_1 = require("../../driving/command/WebConsoleCreateCommand");
const WebConsoleCreateHandler_1 = require("../WebConsoleCreateHandler");
const WebConsoleCollection_1 = require("../../domain/insertion/WebConsoleCollection");
jest.mock('@jfrog-pipelines/logger', () => {
    return {
        LoggerFactory: {
            getLogger: jest.fn().mockReturnValue({
                warn: jest.fn()
            })
        }
    };
});
const logger = logger_1.LoggerFactory.getLogger();
describe('WebConsoleCreateHandler Tests', () => {
    it('should call handle and insert the console logs', async () => {
        const payload = {
            objectId: 1,
            objectType: 'step',
            consoles: [
                {
                    pipleineId: 1,
                    consoleId: 'test'
                }
            ]
        };
        const archivalCommand = new WebConsoleCreateCommand_1.WebConsoleCreateCommand(payload);
        const webConsoleCreateHandler = new WebConsoleCreateHandler_1.WebConsoleCreateHandler(archivalCommand);
        const webConsoleSaveSpied = jest.spyOn(WebConsoleCollection_1.WebConsoleCollection.prototype, 'save').mockResolvedValueOnce();
        await webConsoleCreateHandler.handle();
        expect(webConsoleSaveSpied).toHaveBeenCalledTimes(1);
        expect(webConsoleSaveSpied).toHaveBeenCalledWith();
    });
    it('should log warning if unable to insert the console logs', async () => {
        const payload = {
            objectId: 1,
            objectType: 'step',
            consoles: [
                {
                    pipleineId: 1,
                    consoleId: 'test'
                }
            ]
        };
        const archivalCommand = new WebConsoleCreateCommand_1.WebConsoleCreateCommand(payload);
        const webConsoleCreateHandler = new WebConsoleCreateHandler_1.WebConsoleCreateHandler(archivalCommand);
        const webConsoleSaveSpied = jest.spyOn(WebConsoleCollection_1.WebConsoleCollection.prototype, 'save').mockRejectedValueOnce('error');
        await webConsoleCreateHandler.handle();
        expect(webConsoleSaveSpied).toHaveBeenCalledTimes(1);
        expect(logger.warn).toHaveBeenCalledWith("Unable to insert console logs with 'error'");
    });
    it('should log warning if unable to insert the console logs when console logs are empty', async () => {
        const payload = {
            objectId: 1,
            objectType: 'step',
            consoles: []
        };
        const archivalCommand = new WebConsoleCreateCommand_1.WebConsoleCreateCommand(payload);
        const webConsoleCreateHandler = new WebConsoleCreateHandler_1.WebConsoleCreateHandler(archivalCommand);
        const webConsoleSaveSpied = jest.spyOn(WebConsoleCollection_1.WebConsoleCollection.prototype, 'save').mockRejectedValueOnce('error');
        await webConsoleCreateHandler.handle();
        expect(webConsoleSaveSpied).toHaveBeenCalledTimes(1);
        expect(logger.warn).toHaveBeenCalledWith("Unable to insert console logs with 'error'");
    });
    it('should log warning if unable to insert the console logs when timestampEndedAt is undefined in the console logs for a steplet', async () => {
        const payload = {
            objectId: 1,
            objectType: 'steplet',
            consoles: [
                {
                    pipleineId: 1,
                    consoleId: 'test',
                    timestampEndedAt: undefined
                }
            ]
        };
        const archivalCommand = new WebConsoleCreateCommand_1.WebConsoleCreateCommand(payload);
        const webConsoleCreateHandler = new WebConsoleCreateHandler_1.WebConsoleCreateHandler(archivalCommand);
        const webConsoleSaveSpied = jest.spyOn(WebConsoleCollection_1.WebConsoleCollection.prototype, 'save').mockRejectedValueOnce('error');
        await webConsoleCreateHandler.handle();
        expect(webConsoleSaveSpied).toHaveBeenCalledTimes(1);
        expect(logger.warn).toHaveBeenCalledWith("Unable to insert console logs with 'error'");
    });
    it('should log warning if unable to insert the console logs when timestampEndedAt is undefined in the console logs for a step', async () => {
        const payload = {
            objectId: 1,
            objectType: 'step',
            consoles: [
                {
                    pipleineId: 1,
                    consoleId: 'test',
                    timestampEndedAt: undefined
                }
            ]
        };
        const archivalCommand = new WebConsoleCreateCommand_1.WebConsoleCreateCommand(payload);
        const webConsoleCreateHandler = new WebConsoleCreateHandler_1.WebConsoleCreateHandler(archivalCommand);
        const webConsoleSaveSpied = jest.spyOn(WebConsoleCollection_1.WebConsoleCollection.prototype, 'save').mockRejectedValueOnce('error');
        await webConsoleCreateHandler.handle();
        expect(webConsoleSaveSpied).toHaveBeenCalledTimes(1);
        expect(logger.warn).toHaveBeenCalledWith("Unable to insert console logs with 'error'");
    });
});
//# sourceMappingURL=WebConsoleCreateHandler.test.js.map